@@ -19,8 +19,6 @@
 #ifndef __GNOME_CMD_CHMOD_DIALOG_H__
 #define __GNOME_CMD_CHMOD_DIALOG_H__
 
-G_BEGIN_DECLS
-
 #define GNOME_CMD_CHMOD_DIALOG(obj) \
     GTK_CHECK_CAST (obj, gnome_cmd_chmod_dialog_get_type (), GnomeCmdChmodDialog)
 #define GNOME_CMD_CHMOD_DIALOG_CLASS(klass) \
@@ -47,12 +45,8 @@ struct _GnomeCmdChmodDialogClass
 };
 
 
-GtkWidget*
-gnome_cmd_chmod_dialog_new (GList *files);
+GtkWidget *gnome_cmd_chmod_dialog_new (GList *files);
 
-GtkType
-gnome_cmd_chmod_dialog_get_type (void);
-
-G_END_DECLS
+GtkType gnome_cmd_chmod_dialog_get_type (void);
 
 #endif // __GNOME_CMD_CHMOD_DIALOG_H__
