@@ -28,18 +28,6 @@
 using namespace std;
 
 
-struct _GnomeCmdConFtpPrivate
-{
-    gchar *alias;
-    gchar *host_name;
-    gushort host_port;
-    gchar *remote_dir;
-    gchar *user_name;
-    gchar *pw;
-    gboolean anonymous;
-};
-
-
 static GnomeCmdConClass *parent_class = NULL;
 
 
@@ -49,7 +37,7 @@ static void get_file_info_func (GnomeCmdCon *con)
 
     GnomeVFSFileInfoOptions infoOpts = (GnomeVFSFileInfoOptions) (GNOME_VFS_FILE_INFO_FOLLOW_LINKS | GNOME_VFS_FILE_INFO_GET_MIME_TYPE | GNOME_VFS_FILE_INFO_FORCE_FAST_MIME_TYPE);
 
-    DEBUG('m', "FTP: Connecting to %s\n", gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_NONE));
+    DEBUG('m', "Connecting to %s\n", gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_NONE));
     con->base_info = gnome_vfs_file_info_new ();
 
     GnomeVFSResult res = gnome_vfs_get_file_info_uri (uri, con->base_info, infoOpts);
@@ -89,7 +77,7 @@ static gboolean start_get_file_info (GnomeCmdCon *con)
 
 static void ftp_open (GnomeCmdCon *con)
 {
-    DEBUG('m', "Opening FTP connection\n");
+    DEBUG('m', "Opening remote connection\n");
 
     if (!con->base_path)
     {
@@ -100,12 +88,6 @@ static void ftp_open (GnomeCmdCon *con)
     con->state = CON_STATE_OPENING;
     con->open_result = CON_OPEN_IN_PROGRESS;
 
-    // GnomeCmdPath * path = gnome_cmd_plain_path_new (gnome_cmd_con_ftp_get_remote_dir (GNOME_CMD_CON_FTP (con)));
-    // GnomeCmdDir *dir = gnome_cmd_dir_new (con, path);
-
-    // gnome_cmd_con_set_default_dir (con, dir);
-    // gnome_cmd_con_set_cwd (con, dir);
-
     g_timeout_add (1, (GSourceFunc) start_get_file_info, con);
 }
 
@@ -138,19 +120,13 @@ static gboolean ftp_open_is_needed (GnomeCmdCon *con)
 
 static GnomeVFSURI *ftp_create_uri (GnomeCmdCon *con, GnomeCmdPath *path)
 {
-    GnomeCmdConFtp *ftp_con = GNOME_CMD_CON_FTP (con);
+    g_return_val_if_fail (con->uri != NULL, NULL);
 
-    GnomeVFSURI *u0 = gnome_vfs_uri_new ("ftp:");
+    GnomeVFSURI *u0 = gnome_vfs_uri_new (con->uri);
     GnomeVFSURI *u1 = gnome_vfs_uri_append_path (u0, gnome_cmd_path_get_path (path));
 
     gnome_vfs_uri_unref (u0);
 
-    gnome_vfs_uri_set_host_name (u1, ftp_con->priv->host_name);
-    gnome_vfs_uri_set_host_port (u1, ftp_con->priv->host_port);
-    // gnome_cmd_con_ftp_set_remote_dir (u1, ftp_con->priv->remote_dir);
-    gnome_vfs_uri_set_user_name (u1, ftp_con->priv->user_name);
-    gnome_vfs_uri_set_password (u1, ftp_con->priv->pw);
-
     return u1;
 }
 
@@ -169,14 +145,6 @@ static void destroy (GtkObject *object)
 {
     GnomeCmdConFtp *con = GNOME_CMD_CON_FTP (object);
 
-    g_free (con->priv->alias);
-    g_free (con->priv->host_name);
-    g_free (con->priv->user_name);
-    g_free (con->priv->pw);
-    g_free (con->priv->remote_dir);
-
-    g_free (con->priv);
-
     if (GTK_OBJECT_CLASS (parent_class)->destroy)
         (*GTK_OBJECT_CLASS (parent_class)->destroy) (object);
 }
@@ -241,16 +209,6 @@ static void init (GnomeCmdConFtp *ftp_con)
             g_object_unref (overlay);
         }
     }
-
-    ftp_con->priv = g_new0 (GnomeCmdConFtpPrivate, 1);
-
-    // ftp_con->priv->alias = NULL;
-    // ftp_con->priv->host_name = NULL;
-    // ftp_con->priv->host_port = NULL;
-    // ftp_con->priv->remote_dir = NULL;
-    // ftp_con->priv->user_name = NULL;
-    // ftp_con->priv->pw = NULL;
-    // ftp_con->priv->anonymous = FALSE;
 }
 
 
@@ -291,7 +249,6 @@ GnomeCmdConFtp *gnome_cmd_con_ftp_new (const gchar *alias, const string &text_ur
 
     const gchar *scheme = gnome_vfs_uri_get_scheme (uri);       // do not g_free
     const gchar *host = gnome_vfs_uri_get_host_name (uri);      // do not g_free
-    const guint  port = gnome_vfs_uri_get_host_port (uri);
     const gchar *remote_dir = gnome_vfs_uri_get_path (uri);     // do not g_free
     const gchar *user = gnome_vfs_uri_get_user_name (uri);      // do not g_free
     const gchar *password = gnome_vfs_uri_get_password (uri);   // do not g_free
@@ -302,16 +259,12 @@ GnomeCmdConFtp *gnome_cmd_con_ftp_new (const gchar *alias, const string &text_ur
 
     GnomeCmdCon *con = GNOME_CMD_CON (server);
 
-    gnome_cmd_con_ftp_set_alias (server, alias);
+    gnome_cmd_con_set_alias (con, alias);
     gnome_cmd_con_set_uri (con, text_uri);
+    gnome_cmd_con_set_host_name (con, host);
 
     gnome_cmd_con_ftp_set_host_name (server, host);
-    gnome_cmd_con_ftp_set_host_port (server, port);
-    gnome_cmd_con_ftp_set_remote_dir (server, remote_dir);
-    gnome_cmd_con_ftp_set_user_name (server, user);
-    gnome_cmd_con_ftp_set_pw (server, password);
 
-    // do not set con->alias as it is already done in gnome_cmd_con_ftp_set_alias ()
     con->method = gnome_vfs_uri_is_local (uri) ? CON_LOCAL :
                   g_str_equal (scheme, "ftp")  ? (user && g_str_equal (user, "anonymous") ? CON_ANON_FTP : CON_FTP) :
                   g_str_equal (scheme, "sftp") ? CON_SSH :
@@ -322,8 +275,6 @@ GnomeCmdConFtp *gnome_cmd_con_ftp_new (const gchar *alias, const string &text_ur
 
     con->gnome_auth = !password && con->method!=CON_ANON_FTP;          // ?????????
 
-    con->open_msg = g_strdup_printf (_("Connecting to %s\n"), host);
-
     gnome_vfs_uri_unref (uri);
 
     return server;
@@ -358,99 +309,23 @@ GnomeCmdConFtp *gnome_cmd_con_ftp_new (const gchar *alias, const gchar *host, gu
                                 stringify (_user, user),
                                 stringify (_password, password));
 
-    gnome_cmd_con_ftp_set_alias (server, alias);
+    gnome_cmd_con_set_alias (con, alias);
     gnome_cmd_con_set_uri (con, _uri);
+    gnome_cmd_con_set_host_name (con, _host);
 
     gnome_cmd_con_ftp_set_host_name (server, host);
-    gnome_cmd_con_ftp_set_host_port (server, port);
-    gnome_cmd_con_ftp_set_remote_dir (server, remote_dir);
-    gnome_cmd_con_ftp_set_user_name (server, user);
-    gnome_cmd_con_ftp_set_pw (server, password);
 
-    // do not set con->alias as it is done in gnome_cmd_con_ftp_set_alias ()
     con->gnome_auth = !password && con->method!=CON_ANON_FTP;          // ?????????
 
-    con->open_msg = g_strdup_printf (_("Connecting to %s\n"), host);
-
     return server;
 }
 
 
-void gnome_cmd_con_ftp_set_alias (GnomeCmdConFtp *con, const gchar *alias)
-{
-    g_return_if_fail (con != NULL);
-    g_return_if_fail (con->priv != NULL);
-
-    g_free (con->priv->alias);
-
-    con->priv->alias = g_strdup (alias);
-    gnome_cmd_con_set_alias (GNOME_CMD_CON (con), alias);
-
-    if (!alias)
-        alias = _("<New connection>");
-
-    GNOME_CMD_CON (con)->go_text = g_strdup_printf (_("Go to: %s"), alias);
-    GNOME_CMD_CON (con)->open_text = g_strdup_printf (_("Connect to: %s"), alias);
-    GNOME_CMD_CON (con)->close_text = g_strdup_printf (_("Disconnect from: %s"), alias);
-}
-
-
 void gnome_cmd_con_ftp_set_host_name (GnomeCmdConFtp *con, const gchar *host_name)
 {
     g_return_if_fail (con != NULL);
-    g_return_if_fail (con->priv != NULL);
     g_return_if_fail (host_name != NULL);
 
-    g_free (con->priv->host_name);
-
-    con->priv->host_name = g_strdup (host_name);
-
-    GNOME_CMD_CON (con)->open_tooltip = g_strdup_printf (_("Opens the FTP connection to %s"), host_name);
-    GNOME_CMD_CON (con)->close_tooltip = g_strdup_printf (_("Closes the FTP connection to %s"), host_name);
-}
-
-
-void gnome_cmd_con_ftp_set_host_port (GnomeCmdConFtp *con, gushort host_port)
-{
-    g_return_if_fail (con != NULL);
-    g_return_if_fail (con->priv != NULL);
-
-    con->priv->host_port = host_port;
-}
-
-
-void gnome_cmd_con_ftp_set_remote_dir (GnomeCmdConFtp *con, const gchar *remote_dir)
-{
-    g_return_if_fail (con != NULL);
-    g_return_if_fail (con->priv != NULL);
-
-    g_free (con->priv->remote_dir);
-
-    con->priv->remote_dir = g_strdup (remote_dir);
-}
-
-
-void gnome_cmd_con_ftp_set_user_name (GnomeCmdConFtp *con, const gchar *user_name)
-{
-    g_return_if_fail (con != NULL);
-    g_return_if_fail (con->priv != NULL);
-    g_return_if_fail (user_name != NULL);
-
-    g_free (con->priv->user_name);
-
-    con->priv->user_name = g_strdup (user_name);
-}
-
-
-void gnome_cmd_con_ftp_set_pw (GnomeCmdConFtp *con, const gchar *pw)
-{
-    g_return_if_fail (con != NULL);
-    g_return_if_fail (con->priv != NULL);
-
-    if (pw == con->priv->pw)
-        return;
-
-    g_free (con->priv->pw);
-
-    con->priv->pw = g_strdup (pw);
+    GNOME_CMD_CON (con)->open_tooltip = g_strdup_printf (_("Opens remote connection to %s"), host_name);
+    GNOME_CMD_CON (con)->close_tooltip = g_strdup_printf (_("Closes remote connection to %s"), host_name);
 }
