@@ -27,13 +27,13 @@
 #include "gnome-cmd-plain-path.h"
 #include "gnome-cmd-file-props-dialog.h"
 #include "gnome-cmd-main-win.h"
+#include "gnome-cmd-con-list.h"
 #include "gnome-cmd-xfer.h"
-#include "tags/gnome-cmd-tags-libs.h"
-#include "libgviewer/libgviewer.h"
+#include "tags/gnome-cmd-tags.h"
+#include "intviewer/libgviewer.h"
 
 using namespace std;
 
-
 #define MAX_TYPE_LENGTH 2
 #define MAX_NAME_LENGTH 128
 #define MAX_OWNER_LENGTH 128
@@ -75,33 +75,16 @@ inline GnomeCmdDir *get_parent_dir (GnomeCmdFile *finfo)
  * Gtk class implementation
  *******************************/
 
-static void
-destroy (GtkObject *object)
+static void destroy (GtkObject *object)
 {
     GnomeCmdFile *file = GNOME_CMD_FILE (object);
 
-#ifdef HAVE_EXIF
-    gcmd_tags_libexif_free_metadata(file);
-#endif
-
-#ifdef HAVE_IPTC
-    gcmd_tags_libiptcdata_free_metadata(file);
-#endif
-
-#ifdef HAVE_ICC
-    gcmd_tags_icclib_free_metadata(file);
-#endif
-
-#ifdef HAVE_ID3
-    gcmd_tags_id3lib_free_metadata(file);
-#endif
-
-#ifdef HAVE_GSF
-    gcmd_tags_libgsf_free_metadata(file);
-#endif
+    delete file->metadata;
 
     if (file->info->name[0] != '.')
         DEBUG ('f', "file destroying 0x%p %s\n", file, file->info->name);
+
+    g_free (file->collate_key);
     gnome_vfs_file_info_unref (file->info);
     if (file->priv->dir_handle)
         handle_unref (file->priv->dir_handle);
@@ -119,8 +102,7 @@ destroy (GtkObject *object)
 }
 
 
-static void
-class_init (GnomeCmdFileClass *klass)
+static void class_init (GnomeCmdFileClass *klass)
 {
     GtkObjectClass *object_class = GTK_OBJECT_CLASS (klass);
 
@@ -130,10 +112,10 @@ class_init (GnomeCmdFileClass *klass)
 }
 
 
-static void
-init (GnomeCmdFile *file)
+static void init (GnomeCmdFile *file)
 {
     file->info = NULL;
+    file->collate_key = NULL;
 
     file->priv = g_new0 (GnomeCmdFilePrivate, 1);
     file->priv->dir_handle = NULL;
@@ -149,30 +131,6 @@ init (GnomeCmdFile *file)
     file->priv->last_update.tv_sec = 0;
     file->priv->last_update.tv_usec = 0;
 
-#ifdef HAVE_EXIF
-    file->exif.metadata = NULL;
-    file->exif.accessed = FALSE;
-#endif
-
-#ifdef HAVE_IPTC
-    file->iptc.metadata = NULL;
-    file->iptc.accessed = FALSE;
-#endif
-
-#ifdef HAVE_ICC
-    file->icc.metadata = NULL;
-    file->icc.accessed = FALSE;
-#endif
-
-#ifdef HAVE_ID3
-    file->id3.metadata = NULL;
-    file->id3.accessed = FALSE;
-#endif
-
-#ifdef HAVE_GSF
-    file->gsf.metadata = NULL;
-    file->gsf.accessed = FALSE;
-#endif
 }
 
 
@@ -180,8 +138,7 @@ init (GnomeCmdFile *file)
  * Public functions
  ***********************************/
 
-GtkType
-gnome_cmd_file_get_type         (void)
+GtkType gnome_cmd_file_get_type (void)
 {
     static GtkType type = 0;
 
@@ -205,8 +162,7 @@ gnome_cmd_file_get_type         (void)
 }
 
 
-GnomeCmdFile *
-gnome_cmd_file_new (GnomeVFSFileInfo *info, GnomeCmdDir *dir)
+GnomeCmdFile *gnome_cmd_file_new (GnomeVFSFileInfo *info, GnomeCmdDir *dir)
 {
     GnomeCmdFile *finfo = (GnomeCmdFile *) gtk_type_new (gnome_cmd_file_get_type ());
 
@@ -216,13 +172,22 @@ gnome_cmd_file_new (GnomeVFSFileInfo *info, GnomeCmdDir *dir)
 }
 
 
-void
-gnome_cmd_file_setup (GnomeCmdFile *finfo, GnomeVFSFileInfo *info, GnomeCmdDir *dir)
+void gnome_cmd_file_invalidate_metadata (GnomeCmdFile *finfo)
+{
+    g_return_if_fail (finfo != NULL);
+
+    delete finfo->metadata;
+    finfo->metadata = NULL;
+}
+
+
+void gnome_cmd_file_setup (GnomeCmdFile *finfo, GnomeVFSFileInfo *info, GnomeCmdDir *dir)
 {
     g_return_if_fail (finfo != NULL);
 
     finfo->info = info;
     GNOME_CMD_FILE_INFO (finfo)->info = info;
+    finfo->collate_key = g_utf8_collate_key_for_filename (info->name, -1);
 
     if (dir)
     {
@@ -237,8 +202,7 @@ gnome_cmd_file_setup (GnomeCmdFile *finfo, GnomeVFSFileInfo *info, GnomeCmdDir *
 }
 
 
-void
-gnome_cmd_file_ref (GnomeCmdFile *file)
+void gnome_cmd_file_ref (GnomeCmdFile *file)
 {
     g_return_if_fail (file != NULL);
 
@@ -253,8 +217,7 @@ gnome_cmd_file_ref (GnomeCmdFile *file)
 }
 
 
-void
-gnome_cmd_file_unref (GnomeCmdFile *file)
+void gnome_cmd_file_unref (GnomeCmdFile *file)
 {
     g_return_if_fail (file != NULL);
 
@@ -268,8 +231,7 @@ gnome_cmd_file_unref (GnomeCmdFile *file)
 }
 
 
-GnomeVFSResult
-gnome_cmd_file_chmod (GnomeCmdFile *file, GnomeVFSFilePermissions perm)
+GnomeVFSResult gnome_cmd_file_chmod (GnomeCmdFile *file, GnomeVFSFilePermissions perm)
 {
     g_return_val_if_fail (file != NULL, GNOME_VFS_ERROR_CORRUPTED_DATA);
     g_return_val_if_fail (file->info != NULL, GNOME_VFS_ERROR_CORRUPTED_DATA);
@@ -282,15 +244,16 @@ gnome_cmd_file_chmod (GnomeCmdFile *file, GnomeVFSFilePermissions perm)
     if (has_parent_dir (file))
     {
         GnomeCmdDir *dir = get_parent_dir (file);
-        gnome_cmd_dir_file_changed (dir, file->info->name);
+        gchar *uri_str = gnome_cmd_file_get_uri_str (file);
+        gnome_cmd_dir_file_changed (dir, uri_str);
+        g_free (uri_str);
     }
 
     return ret;
 }
 
 
-GnomeVFSResult
-gnome_cmd_file_chown (GnomeCmdFile *file, uid_t uid, gid_t gid)
+GnomeVFSResult gnome_cmd_file_chown (GnomeCmdFile *file, uid_t uid, gid_t gid)
 {
     g_return_val_if_fail (file != NULL, GNOME_VFS_ERROR_CORRUPTED_DATA);
     g_return_val_if_fail (file->info != NULL, GNOME_VFS_ERROR_CORRUPTED_DATA);
@@ -306,19 +269,22 @@ gnome_cmd_file_chown (GnomeCmdFile *file, uid_t uid, gid_t gid)
     if (has_parent_dir (file))
     {
         GnomeCmdDir *dir = get_parent_dir (file);
-        gnome_cmd_dir_file_changed (dir, file->info->name);
+        gchar *uri_str = gnome_cmd_file_get_uri_str (file);
+        gnome_cmd_dir_file_changed (dir, uri_str);
+        g_free (uri_str);
     }
 
     return ret;
 }
 
 
-GnomeVFSResult
-gnome_cmd_file_rename (GnomeCmdFile *finfo, const gchar *new_name)
+GnomeVFSResult gnome_cmd_file_rename (GnomeCmdFile *finfo, const gchar *new_name)
 {
     g_return_val_if_fail (finfo, GNOME_VFS_ERROR_CORRUPTED_DATA);
     g_return_val_if_fail (finfo->info, GNOME_VFS_ERROR_CORRUPTED_DATA);
 
+    gchar *old_uri_str = gnome_cmd_file_get_uri_str (finfo);
+
     GnomeVFSFileInfo *new_info = gnome_vfs_file_info_dup (finfo->info);
     g_return_val_if_fail (new_info, GNOME_VFS_ERROR_CORRUPTED_DATA);
 
@@ -332,7 +298,7 @@ gnome_cmd_file_rename (GnomeCmdFile *finfo, const gchar *new_name)
     if (result == GNOME_VFS_OK && has_parent_dir (finfo))
     {
         gnome_cmd_file_update_info (finfo, new_info);
-        gnome_cmd_dir_file_renamed (get_parent_dir (finfo), finfo);
+        gnome_cmd_dir_file_renamed (get_parent_dir (finfo), finfo, old_uri_str);
         if (GNOME_CMD_IS_DIR (finfo))
             gnome_cmd_dir_update_path (GNOME_CMD_DIR (finfo));
     }
@@ -355,12 +321,12 @@ gchar *gnome_cmd_file_get_path (GnomeCmdFile *finfo)
     g_return_val_if_fail (finfo != NULL, NULL);
     g_return_val_if_fail (finfo->info != NULL, NULL);
 
-    gchar *path_str;
-    GnomeCmdPath *path;
-
     if (strcmp (finfo->info->name, G_DIR_SEPARATOR_S) == 0)
         return g_strdup (G_DIR_SEPARATOR_S);
 
+    GnomeCmdPath *path;
+    gchar *path_str;
+
     if (!has_parent_dir (finfo))
     {
         if (GNOME_CMD_IS_DIR (finfo))
@@ -379,11 +345,10 @@ gchar *gnome_cmd_file_get_path (GnomeCmdFile *finfo)
 }
 
 
-gchar *
-gnome_cmd_file_get_real_path (GnomeCmdFile *finfo)
+gchar *gnome_cmd_file_get_real_path (GnomeCmdFile *finfo)
 {
     GnomeVFSURI *uri = gnome_cmd_file_get_uri (finfo);
-    gchar *path = gnome_vfs_unescape_string(gnome_vfs_uri_get_path (uri), NULL);
+    gchar *path = gnome_vfs_unescape_string (gnome_vfs_uri_get_path (uri), NULL);
 
     gnome_vfs_uri_unref (uri);
 
@@ -391,24 +356,41 @@ gnome_cmd_file_get_real_path (GnomeCmdFile *finfo)
 }
 
 
-gchar *
-gnome_cmd_file_get_quoted_real_path (GnomeCmdFile *finfo)
+gchar *gnome_cmd_file_get_quoted_real_path (GnomeCmdFile *finfo)
 {
-    gchar *ret = NULL;
     gchar *path = gnome_cmd_file_get_real_path (finfo);
+    gchar *ret = path ? quote_if_needed (path) : NULL;
 
-    if (path)
-    {
-        ret = quote_if_needed (path);
-        g_free (path);
-    }
+    g_free (path);
 
     return ret;
 }
 
 
-GnomeVFSURI *
-gnome_cmd_file_get_uri (GnomeCmdFile *finfo)
+gchar *gnome_cmd_file_get_dirname (GnomeCmdFile *finfo)
+{
+    GnomeVFSURI *uri = gnome_cmd_file_get_uri (finfo);
+    gchar *path = gnome_vfs_uri_extract_dirname (uri);
+
+    gnome_vfs_uri_unref (uri);
+
+    return path;
+}
+
+
+gchar *gnome_cmd_file_get_unescaped_dirname (GnomeCmdFile *finfo)
+{
+    GnomeVFSURI *uri = gnome_cmd_file_get_uri (finfo);
+    gchar *path = gnome_vfs_uri_extract_dirname (uri);
+    gnome_vfs_uri_unref (uri);
+    gchar *unescaped_path = gnome_vfs_unescape_string (path, NULL);
+    g_free (path);
+
+    return unescaped_path;
+}
+
+
+GnomeVFSURI *gnome_cmd_file_get_uri (GnomeCmdFile *finfo)
 {
     g_return_val_if_fail (GNOME_CMD_IS_FILE (finfo), NULL);
 
@@ -428,43 +410,34 @@ gnome_cmd_file_get_uri (GnomeCmdFile *finfo)
 }
 
 
-gchar *
-gnome_cmd_file_get_uri_str (GnomeCmdFile *finfo)
+gchar *gnome_cmd_file_get_uri_str (GnomeCmdFile *finfo, GnomeVFSURIHideOptions hide_options)
 {
     g_return_val_if_fail (GNOME_CMD_IS_FILE (finfo), NULL);
 
     GnomeVFSURI *uri = gnome_cmd_file_get_uri (finfo);
-    gchar *uri_str = gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_NONE);
+    gchar *uri_str = gnome_vfs_uri_to_string (uri, hide_options);
     gnome_vfs_uri_unref (uri);
 
     return uri_str;
 }
 
 
-const gchar *
-gnome_cmd_file_get_extension (GnomeCmdFile *file)
+const gchar *gnome_cmd_file_get_extension (GnomeCmdFile *file)
 {
-    gint i, len;
-
     g_return_val_if_fail (file != NULL, NULL);
     g_return_val_if_fail (file->info != NULL, NULL);
 
     if (file->info->type == GNOME_VFS_FILE_TYPE_DIRECTORY)
         return NULL;
 
-    len = strlen (file->info->name);
-    for (i=len; i>0; i--)
-    {
-        if (file->info->name[i] == '.')
-            return &file->info->name[i+1];
-    }
+    const char *s = strrchr (file->info->name, '.');        // does NOT work on UTF-8 strings, should be (MUCH SLOWER):
+    // const char *s = g_utf8_strrchr (file->info->name, -1, '.');
 
-    return NULL;
+    return s ? s+1 : NULL;
 }
 
 
-const gchar *
-gnome_cmd_file_get_owner (GnomeCmdFile *file)
+const gchar *gnome_cmd_file_get_owner (GnomeCmdFile *file)
 {
     g_return_val_if_fail (file != NULL, NULL);
     g_return_val_if_fail (file->info != NULL, NULL);
@@ -483,8 +456,7 @@ gnome_cmd_file_get_owner (GnomeCmdFile *file)
 }
 
 
-const gchar *
-gnome_cmd_file_get_group (GnomeCmdFile *file)
+const gchar *gnome_cmd_file_get_group (GnomeCmdFile *file)
 {
     g_return_val_if_fail (file != NULL, NULL);
     g_return_val_if_fail (file->info != NULL, NULL);
@@ -509,9 +481,7 @@ inline const gchar *date2string (time_t date, gboolean overide_disp_setting)
 }
 
 
-const gchar *
-gnome_cmd_file_get_adate (GnomeCmdFile *file,
-                          gboolean overide_disp_setting)
+const gchar *gnome_cmd_file_get_adate (GnomeCmdFile *file, gboolean overide_disp_setting)
 {
     g_return_val_if_fail (file != NULL, NULL);
     g_return_val_if_fail (file->info != NULL, NULL);
@@ -520,9 +490,7 @@ gnome_cmd_file_get_adate (GnomeCmdFile *file,
 }
 
 
-const gchar *
-gnome_cmd_file_get_mdate (GnomeCmdFile *file,
-                          gboolean overide_disp_setting)
+const gchar *gnome_cmd_file_get_mdate (GnomeCmdFile *file, gboolean overide_disp_setting)
 {
     g_return_val_if_fail (file != NULL, NULL);
     g_return_val_if_fail (file->info != NULL, NULL);
@@ -531,9 +499,7 @@ gnome_cmd_file_get_mdate (GnomeCmdFile *file,
 }
 
 
-const gchar *
-gnome_cmd_file_get_cdate (GnomeCmdFile *file,
-                          gboolean overide_disp_setting)
+const gchar *gnome_cmd_file_get_cdate (GnomeCmdFile *file, gboolean overide_disp_setting)
 {
     g_return_val_if_fail (file != NULL, NULL);
     g_return_val_if_fail (file->info != NULL, NULL);
@@ -542,8 +508,7 @@ gnome_cmd_file_get_cdate (GnomeCmdFile *file,
 }
 
 
-const gchar *
-gnome_cmd_file_get_size (GnomeCmdFile *file)
+const gchar *gnome_cmd_file_get_size (GnomeCmdFile *file)
 {
     static gchar dir_indicator[] = "<DIR> ";
 
@@ -578,7 +543,7 @@ GnomeVFSFileSize gnome_cmd_file_get_tree_size (GnomeCmdFile *file)
 }
 
 
-const gchar * gnome_cmd_file_get_tree_size_as_str (GnomeCmdFile *file)
+const gchar *gnome_cmd_file_get_tree_size_as_str (GnomeCmdFile *file)
 {
     g_return_val_if_fail (file != NULL, NULL);
     g_return_val_if_fail (file->info != NULL, NULL);
@@ -593,7 +558,7 @@ const gchar * gnome_cmd_file_get_tree_size_as_str (GnomeCmdFile *file)
 }
 
 
-const gchar * gnome_cmd_file_get_perm (GnomeCmdFile *file)
+const gchar *gnome_cmd_file_get_perm (GnomeCmdFile *file)
 {
     static gchar perm_str[MAX_PERM_LENGTH];
 
@@ -605,8 +570,7 @@ const gchar * gnome_cmd_file_get_perm (GnomeCmdFile *file)
 }
 
 
-const gchar *
-gnome_cmd_file_get_type_string (GnomeCmdFile *finfo)
+const gchar *gnome_cmd_file_get_type_string (GnomeCmdFile *finfo)
 {
     static gchar type_str[MAX_TYPE_LENGTH];
 
@@ -618,10 +582,9 @@ gnome_cmd_file_get_type_string (GnomeCmdFile *finfo)
 }
 
 
-const gchar *
-gnome_cmd_file_get_type_desc (GnomeCmdFile *finfo)
+const gchar *gnome_cmd_file_get_type_desc (GnomeCmdFile *finfo)
 {
-    static gchar *type_strings[] = {
+    static const gchar *type_strings[] = {
         N_("Unknown file type"),
         N_("Regular file"),
         N_("Directory"),
@@ -642,8 +605,7 @@ gnome_cmd_file_get_type_desc (GnomeCmdFile *finfo)
 }
 
 
-GdkPixmap *
-gnome_cmd_file_get_type_pixmap (GnomeCmdFile *finfo)
+GdkPixmap *gnome_cmd_file_get_type_pixmap (GnomeCmdFile *finfo)
 {
     g_return_val_if_fail (finfo != NULL, NULL);
     g_return_val_if_fail (finfo->info != NULL, NULL);
@@ -657,8 +619,7 @@ gnome_cmd_file_get_type_pixmap (GnomeCmdFile *finfo)
 }
 
 
-GdkBitmap *
-gnome_cmd_file_get_type_mask (GnomeCmdFile *finfo)
+GdkBitmap *gnome_cmd_file_get_type_mask (GnomeCmdFile *finfo)
 {
     g_return_val_if_fail (finfo != NULL, NULL);
     g_return_val_if_fail (finfo->info != NULL, NULL);
@@ -672,8 +633,7 @@ gnome_cmd_file_get_type_mask (GnomeCmdFile *finfo)
 }
 
 
-const gchar *
-gnome_cmd_file_get_mime_type (GnomeCmdFile *finfo)
+const gchar *gnome_cmd_file_get_mime_type (GnomeCmdFile *finfo)
 {
     g_return_val_if_fail (finfo != NULL, NULL);
     g_return_val_if_fail (finfo->info != NULL, NULL);
@@ -682,18 +642,16 @@ gnome_cmd_file_get_mime_type (GnomeCmdFile *finfo)
 }
 
 
-const gchar *
-gnome_cmd_file_get_mime_type_desc (GnomeCmdFile *finfo)
+const gchar *gnome_cmd_file_get_mime_type_desc (GnomeCmdFile *finfo)
 {
     g_return_val_if_fail (finfo != NULL, NULL);
     g_return_val_if_fail (finfo->info != NULL, NULL);
 
-    return gnome_vfs_mime_get_description (finfo->info->mime_type);
+    return finfo->info->mime_type ? gnome_vfs_mime_get_description (finfo->info->mime_type) : NULL;
 }
 
 
-gboolean
-gnome_cmd_file_has_mime_type (GnomeCmdFile *finfo, const gchar *mime_type)
+gboolean gnome_cmd_file_has_mime_type (GnomeCmdFile *finfo, const gchar *mime_type)
 {
     g_return_val_if_fail (finfo != NULL, FALSE);
     g_return_val_if_fail (finfo->info != NULL, FALSE);
@@ -715,8 +673,7 @@ gboolean gnome_cmd_file_mime_begins_with (GnomeCmdFile *finfo, const gchar *mime
 }
 
 
-void
-gnome_cmd_file_show_properties (GnomeCmdFile *finfo)
+void gnome_cmd_file_show_properties (GnomeCmdFile *finfo)
 {
     GtkWidget *dialog = gnome_cmd_file_props_dialog_create (finfo);
     if (!dialog) return;
@@ -726,32 +683,25 @@ gnome_cmd_file_show_properties (GnomeCmdFile *finfo)
 }
 
 
-static void
-do_view_file (const gchar *path, gint internal_viewer)
+static void do_view_file (const gchar *path, gint internal_viewer)
 {
-    gchar *arg;
-    gchar *command;
-    GViewer *viewer;
-
     if (internal_viewer==-1)
         internal_viewer = gnome_cmd_data_get_use_internal_viewer ();
 
     switch (internal_viewer)
     {
         case TRUE : {
-                        arg = gnome_vfs_unescape_string (path, NULL);
-                        viewer = (GViewer *) gviewer_window_file_view(arg, NULL);
-                        gtk_widget_show(GTK_WIDGET(viewer));
+                        GViewer *viewer = (GViewer *) gviewer_window_file_view (path, NULL);
+                        gtk_widget_show (GTK_WIDGET(viewer));
                         gdk_window_set_icon (GTK_WIDGET(viewer)->window, NULL,
                                              IMAGE_get_pixmap (PIXMAP_INTERNAL_VIEWER),
                                              IMAGE_get_mask (PIXMAP_INTERNAL_VIEWER));
-                        g_free(arg);
                     }
                     break;
 
         case FALSE: {
-                        arg = g_shell_quote (path);
-                        command = g_strdup_printf (gnome_cmd_data_get_viewer (), arg);
+                        gchar *arg = g_shell_quote (path);
+                        gchar *command = g_strdup_printf (gnome_cmd_data_get_viewer (), arg);
                         run_command (command, FALSE);
                         g_free (arg);
                         g_free (command);
@@ -761,8 +711,7 @@ do_view_file (const gchar *path, gint internal_viewer)
 }
 
 
-static void
-on_file_downloaded_for_view (gchar *path)
+static void on_file_downloaded_for_view (gchar *path)
 {
     do_view_file (path,-1);
 
@@ -770,8 +719,7 @@ on_file_downloaded_for_view (gchar *path)
 }
 
 
-void
-gnome_cmd_file_view (GnomeCmdFile *finfo, gint internal_viewer)
+void gnome_cmd_file_view (GnomeCmdFile *finfo, gint internal_viewer)
 {
     g_return_if_fail (finfo != NULL);
     g_return_if_fail (has_parent_dir (finfo));
@@ -779,7 +727,6 @@ gnome_cmd_file_view (GnomeCmdFile *finfo, gint internal_viewer)
     gchar *path_str;
     GnomeCmdPath *path;
     GnomeVFSURI *src_uri, *dest_uri;
-    GnomeCmdCon *con;
 
     // If the file is local there is no need to download it
     if (gnome_cmd_dir_is_local (get_parent_dir (finfo)))
@@ -796,8 +743,7 @@ gnome_cmd_file_view (GnomeCmdFile *finfo, gint internal_viewer)
 
     path = gnome_cmd_plain_path_new (path_str);
     src_uri = gnome_cmd_file_get_uri (finfo);
-    con = gnome_cmd_con_list_get_home (gnome_cmd_data_get_con_list ());
-    dest_uri = gnome_cmd_con_create_uri (con, path);
+    dest_uri = gnome_cmd_con_create_uri (get_home_con (), path);
 
     g_printerr ("Copying to: %s\n", path_str);
     gtk_object_destroy (GTK_OBJECT (path));
@@ -811,55 +757,54 @@ gnome_cmd_file_view (GnomeCmdFile *finfo, gint internal_viewer)
 }
 
 
-void
-gnome_cmd_file_edit (GnomeCmdFile *finfo)
+void gnome_cmd_file_edit (GnomeCmdFile *finfo)
 {
     g_return_if_fail (finfo != NULL);
 
-    gchar *fpath = gnome_cmd_file_get_real_path (finfo);
-    gchar *arg = g_shell_quote (fpath);
-    gchar *command = g_strdup_printf (gnome_cmd_data_get_editor (), arg);
+    if (!gnome_cmd_file_is_local (finfo))
+        return;
 
-    run_command (command, FALSE);
+    gchar *fpath = gnome_cmd_file_get_quoted_real_path (finfo);
+    gchar *dpath = gnome_cmd_file_get_unescaped_dirname (finfo);
+    gchar *command = g_strdup_printf (gnome_cmd_data_get_editor (), fpath);
+
+    run_command_indir (command, dpath, FALSE);
 
     g_free (command);
+    g_free (dpath);
     g_free (fpath);
-    g_free (arg);
 }
 
 
-void
-gnome_cmd_file_show_cap_cut (GnomeCmdFile *finfo)
+void gnome_cmd_file_show_cap_cut (GnomeCmdFile *finfo)
 {
 }
 
 
-void
-gnome_cmd_file_show_cap_copy (GnomeCmdFile *finfo)
+void gnome_cmd_file_show_cap_copy (GnomeCmdFile *finfo)
 {
 }
 
 
-void
-gnome_cmd_file_show_cap_paste (GnomeCmdFile *finfo)
+void gnome_cmd_file_show_cap_paste (GnomeCmdFile *finfo)
 {
 }
 
 
-void
-gnome_cmd_file_update_info (GnomeCmdFile *finfo, GnomeVFSFileInfo *info)
+void gnome_cmd_file_update_info (GnomeCmdFile *finfo, GnomeVFSFileInfo *info)
 {
     g_return_if_fail (finfo != NULL);
     g_return_if_fail (info != NULL);
 
+    g_free (finfo->collate_key);
     gnome_vfs_file_info_unref (finfo->info);
     gnome_vfs_file_info_ref (info);
     finfo->info = info;
+    finfo->collate_key = g_utf8_collate_key_for_filename (info->name, -1);
 }
 
 
-gboolean
-gnome_cmd_file_is_local (GnomeCmdFile *finfo)
+gboolean gnome_cmd_file_is_local (GnomeCmdFile *finfo)
 {
     g_return_val_if_fail (GNOME_CMD_IS_FILE (finfo), FALSE);
 
@@ -867,8 +812,7 @@ gnome_cmd_file_is_local (GnomeCmdFile *finfo)
 }
 
 
-gboolean
-gnome_cmd_file_is_executable (GnomeCmdFile *finfo)
+gboolean gnome_cmd_file_is_executable (GnomeCmdFile *finfo)
 {
     g_return_val_if_fail (GNOME_CMD_IS_FILE (finfo), FALSE);
 
@@ -897,8 +841,7 @@ gnome_cmd_file_is_executable (GnomeCmdFile *finfo)
 }
 
 
-void
-gnome_cmd_file_is_deleted (GnomeCmdFile *finfo)
+void gnome_cmd_file_is_deleted (GnomeCmdFile *finfo)
 {
     g_return_if_fail (GNOME_CMD_IS_FILE (finfo));
 
@@ -911,8 +854,7 @@ gnome_cmd_file_is_deleted (GnomeCmdFile *finfo)
 }
 
 
-void
-gnome_cmd_file_execute (GnomeCmdFile *finfo)
+void gnome_cmd_file_execute (GnomeCmdFile *finfo)
 {
     gchar *fpath = gnome_cmd_file_get_real_path (finfo);
     gchar *dpath = g_path_get_dirname (fpath);
@@ -940,8 +882,7 @@ gnome_cmd_file_execute (GnomeCmdFile *finfo)
 *
 ******************************************************************************/
 
-GList *
-gnome_cmd_file_list_copy (GList *files)
+GList *gnome_cmd_file_list_copy (GList *files)
 {
     g_return_val_if_fail (files != NULL, NULL);
 
@@ -964,8 +905,7 @@ gnome_cmd_file_list_copy (GList *files)
 *
 ******************************************************************************/
 
-void
-gnome_cmd_file_list_free (GList *files)
+void gnome_cmd_file_list_free (GList *files)
 {
     if (!files) return;
 
@@ -988,8 +928,7 @@ gnome_cmd_file_list_free (GList *files)
 *
 ******************************************************************************/
 
-void
-gnome_cmd_file_list_ref (GList *files)
+void gnome_cmd_file_list_ref (GList *files)
 {
     g_return_if_fail (files != NULL);
 
@@ -1021,7 +960,7 @@ void gnome_cmd_file_list_unref (GList *files)
 
 inline gulong tv2ms (const GTimeVal &t)
 {
-    return t.tv_sec * 1000 + t.tv_usec/1000;
+    return t.tv_sec*1000 + t.tv_usec/1000;
 }
 
 
