@@ -39,6 +39,7 @@ struct _GnomeCmdFile
     GnomeCmdFileInfo parent;
 
     GnomeVFSFileInfo *info;
+    gchar *collate_key;                 // necessary for proper sorting of UTF-8 encoded file names
     GnomeCmdFilePrivate *priv;
     GnomeCmdFileMetadata *metadata;
 };
@@ -57,6 +58,8 @@ GtkType gnome_cmd_file_get_type (void);
 GnomeCmdFile *gnome_cmd_file_new (GnomeVFSFileInfo *info, GnomeCmdDir *dir);
 void gnome_cmd_file_setup (GnomeCmdFile *finfo, GnomeVFSFileInfo *info, GnomeCmdDir *dir);
 
+void gnome_cmd_file_invalidate_metadata (GnomeCmdFile *finfo);
+
 void gnome_cmd_file_ref (GnomeCmdFile *finfo);
 void gnome_cmd_file_unref (GnomeCmdFile *finfo);
 
