@@ -21,11 +21,8 @@
 #define __GNOME_CMD_INCLUDES_H__
 
 #include <libgcmd/libgcmd.h>
-
-G_BEGIN_DECLS
+#include <gtk/gtkmarshal.h>
 
 typedef void *(*PthreadFunc)(void *);
 
-G_END_DECLS
-
 #endif // __GNOME_CMD_INCLUDES_H__
