@@ -38,10 +38,10 @@
 #include "gnome-cmd-prepare-move-dialog.h"
 #include "gnome-cmd-python-plugin.h"
 #include "gnome-cmd-search-dialog.h"
+#include "gnome-cmd-key-shortcuts-dialog.h"
 #include "gnome-cmd-user-actions.h"
 #include "plugin_manager.h"
 #include "cap.h"
-#include "dict.h"
 #include "utils.h"
 
 using namespace std;
@@ -100,9 +100,6 @@ inline gboolean append_real_path (string &s, GnomeCmdFile *finfo)
 GnomeCmdUserActions gcmd_user_actions;
 
 
-static DICT<GnomeCmdUserActionFunc> actions(NULL);
-
-
 inline bool operator < (const GdkEventKey &e1, const GdkEventKey &e2)
 {
     if (e1.keyval < e2.keyval)
@@ -111,163 +108,106 @@ inline bool operator < (const GdkEventKey &e1, const GdkEventKey &e2)
     if (e1.keyval > e2.keyval)
         return false;
 
+#ifdef HAVE_GTK_2_10
+    return (e1.state & (GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK | GDK_SUPER_MASK | GDK_HYPER_MASK | GDK_META_MASK)) < (e2.state & (GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK | GDK_SUPER_MASK | GDK_HYPER_MASK | GDK_META_MASK));
+#else
     return (e1.state & (GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK | GDK_MOD4_MASK)) < (e2.state & (GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK | GDK_MOD4_MASK));
+#endif
 }
 
 
-inline gboolean ascii_isalnum (guint key_val)
+DICT<GnomeCmdUserActionFunc> GnomeCmdUserActions::action_func;
+DICT<GnomeCmdUserActionFunc> GnomeCmdUserActions::action_name;
+
+
+struct UserActionData
 {
-    return key_val<=G_MAXUINT8 && g_ascii_isalnum (key_val);
-}
+    GnomeCmdUserActionFunc func;
+    const gchar *name;
+    const gchar *description;
+};
 
 
-inline gboolean ascii_isalpha (guint key_val)
-{
-    return key_val<=G_MAXUINT8 && g_ascii_isalpha (key_val);
-}
-
-
-inline string key2str(guint state, guint key_val)
-{
-    string key_name;
-
-    if (state & GDK_SHIFT_MASK)    key_name += gdk_modifiers_names[GDK_SHIFT_MASK];
-    if (state & GDK_CONTROL_MASK)  key_name += gdk_modifiers_names[GDK_CONTROL_MASK];
-    if (state & GDK_MOD1_MASK)     key_name += gdk_modifiers_names[GDK_MOD1_MASK];
-    if (state & GDK_MOD4_MASK)     key_name += gdk_modifiers_names[GDK_MOD4_MASK];
-
-    if (ascii_isalnum (key_val))
-        key_name += g_ascii_tolower (key_val);
-    else
-        key_name += gdk_key_names[key_val];
-
-    return key_name;
-}
-
-
-inline string key2str(const GdkEventKey &event)
-{
-    return key2str(event.state, event.keyval);
-}
-
-
-inline GdkEventKey str2key(gchar *s, guint &state, guint &key_val)
-{
-    g_strdown (s);
-
-    gchar *key = strrchr(s, '>');       // find last '>'
-    key = key ? key+1 : s;
-
-    key_val = gdk_key_names[key];
-    state = 0;
-
-     if (key_val==GDK_VoidSymbol)
-        if (strlen(key)==1 && ascii_isalnum (*key))
-            key_val = *key;
-
-    for (const gchar *beg=s; (beg=strchr(beg, '<')); ++beg)
-    {
-        if (const gchar *end = strchr(beg, '>'))
-            if (guint modifier = gdk_modifiers_names[string(beg,end-beg+1)])
-            {
-                state |= modifier;
-                beg = end;
-                continue;
-            }
-
-        key_val = GDK_VoidSymbol;
-        break;
-    }
-
-    GdkEventKey event;
-
-    event.keyval = key_val;
-    event.state = state;
-
-    return event;
-}
-
-
-inline GdkEventKey str2key(gchar *s, GdkEventKey &event)
-{
-    return str2key(s, event.state, event.keyval);
-}
-
-
-inline GdkEventKey str2key(gchar *s)
-{
-    GdkEventKey event;
-
-    return str2key(s, event);
-}
+static UserActionData user_actions_data[] = {
+                                             {bookmarks_add_current, "bookmarks.add_current", N_("Bookmark current directory")},
+                                             {bookmarks_edit, "bookmarks.edit", N_("Manage bookmarks")},
+                                             {bookmarks_goto, "bookmarks.goto", N_("Go to bookmarked location")},
+                                             {command_execute, "command.execute", N_("Execute command")},
+                                             {command_open_nautilus, "command.open_folder", N_("Open folder")},
+                                             {command_open_terminal, "command.open_terminal", N_("Open terminal")},
+                                             {command_root_mode, "command.root_mode", N_("Start GNOME Commander as root")},
+                                             {connections_close_current, "connections.close", N_("Close connection")},
+                                             {connections_new, "connections.new", N_("New connection")},
+                                             {connections_open, "connections.open", N_("Open connection")},
+                                             {edit_cap_copy, "edit.copy", N_("Copy")},
+                                             {edit_copy_fnames, "edit.copy_filenames", N_("Copy file names")},
+                                             {edit_cap_cut, "edit.cut", N_("Cut")},
+                                             {file_delete, "edit.delete", N_("Delete")},
+                                             {edit_filter, "edit.filter", N_("Show user defined files")},
+                                             {edit_cap_paste, "edit.paste", N_("Paste")},
+                                             {edit_quick_search, "edit.quick_search", N_("Quick search")},
+                                             {edit_search, "edit.search", N_("Search")},
+                                             {file_advrename, "file.advrename", N_("Advanced rename tool")},
+                                             {file_chmod, "file.chmod", N_("Change permissions")},
+                                             {file_chown, "file.chown", N_("Change owner/group")},
+                                             {file_copy, "file.copy", N_("Copy files")},
+                                             {file_create_symlink, "file.create_symlink", N_("Create symbolic link")},
+                                             {file_delete, "file.delete", N_("Delete files")},
+                                             {file_diff, "file.diff", N_("Compare files (diff)")},
+                                             {file_edit, "file.edit", N_("Edit file")},
+                                             {file_edit_new_doc, "file.edit_new_doc", N_("Edit a new file")},
+                                             {file_exit, "file.exit", N_("Quit")},
+                                             {file_external_view, "file.external_view", N_("View with external viewer")},
+                                             {file_internal_view, "file.internal_view", N_("View with internal viewer")},
+                                             {file_mkdir, "file.mkdir", N_("Create directory")},
+                                             {file_move, "file.move", N_("Move files")},
+                                             {file_properties, "file.properties", N_("Properties")},
+                                             {file_rename, "file.rename", N_("Rename files")},
+                                             // {file_run, "file.run"},
+                                             {file_sendto, "file.sendto", N_("Send files")},
+                                             {file_sync_dirs, "file.synchronize_directories", N_("Synchonize directories")},
+                                             // {file_umount, "file.umount"},
+                                             {file_view, "file.view", N_("View file")},
+                                             {help_about, "help.about", N_("About GNOME Commander")},
+                                             {help_help, "help.help", N_("Help contents")},
+                                             {help_keyboard, "help.keyboard", N_("Help on keyboard shortcuts")},
+                                             {help_problem, "help.problem", N_("Report a problem")},
+                                             {help_web, "help.web", N_("GNOME Commander on the web")},
+                                             {mark_compare_directories, "mark.compare_directories", N_("Compare directories")},
+                                             {mark_invert_selection, "mark.invert", N_("Invert selection")},
+                                             {mark_select_all, "mark.select_all", N_("Select all")},
+                                             {mark_toggle, "mark.toggle", N_("Toggle selection")},
+                                             {mark_toggle_and_step, "mark.toggle_and_step", N_("Toggle selection and move cursor downward")},
+                                             {mark_unselect_all, "mark.unselect_all", N_("Unselect all")},
+                                             {no_action, "no.action", N_("Do nothing")},
+                                             {options_edit, "options.edit", N_("Options")},
+                                             {options_edit_mime_types, "options.edit_mime_types", N_("MIME types")},
+                                             {options_edit_shortcuts, "options.shortcuts", N_("Keyboard shortcuts")},
+                                             {plugins_configure, "plugins.configure", N_("Configure plugins")},
+                                             {plugins_execute_python, "plugins.execute_python", N_("Execute python plugin")},
+                                             {view_back, "view.back", N_("Back one directory")},
+                                             {view_equal_panes, "view.equal_panes", N_("Equal panel size")},
+                                             {view_first, "view.first", N_("Back to the first directory")},
+                                             {view_forward, "view.forward", N_("Forward one directory")},
+                                             {view_home, "view.home", N_("Home directory")},
+                                             {view_in_active_pane, "view.in_active_pane", N_("Open directory in the active window")},
+                                             {view_in_inactive_pane, "view.in_inactive_pane", N_("Open directory in the inactive window")},
+                                             {view_in_left_pane, "view.in_left_pane", N_("Open directory in the left window")},
+                                             {view_in_right_pane, "view.in_right_pane", N_("Open directory in the right window")},
+                                             {view_last, "view.last", N_("Forward to the last directory")},
+                                             {view_refresh, "view.refresh", N_("Refresh")},
+                                             {view_root, "view.root", N_("Root directory")},
+                                             {view_up, "view.up", N_("Up one directory")},
+                                            };
 
 
 void GnomeCmdUserActions::init()
 {
-    actions.add(bookmarks_add_current, "bookmarks.add_current");
-    actions.add(bookmarks_edit, "bookmarks.edit");
-    actions.add(bookmarks_goto, "bookmarks.goto");
-    actions.add(command_open_terminal, "command.open_terminal");
-    actions.add(connections_close_current, "connections.close");
-    actions.add(connections_new, "connections.new");
-    actions.add(connections_open, "connections.open");
-    actions.add(edit_cap_copy, "edit.copy");
-    actions.add(edit_copy_fnames, "edit.copy_filenames");
-    actions.add(edit_cap_cut, "edit.cut");
-    actions.add(file_delete, "edit.delete");
-    actions.add(edit_filter, "edit.filter");
-    actions.add(edit_cap_paste, "edit.paste");
-    actions.add(edit_quick_search, "edit.quick_search");
-    actions.add(edit_search, "edit.search");
-    actions.add(file_advrename, "file.advrename");
-    actions.add(file_chmod, "file.chmod");
-    actions.add(file_chown, "file.chown");
-    actions.add(file_copy, "file.copy");
-    actions.add(file_create_symlink, "file.create_symlink");
-    actions.add(file_delete, "file.delete");
-    actions.add(file_diff, "file.diff");
-    actions.add(file_edit, "file.edit");
-    actions.add(file_edit_new_doc, "file.edit_new_doc");
-    actions.add(file_exit, "file.exit");
-    actions.add(file_external_view, "file.external_view");
-    actions.add(file_internal_view, "file.internal_view");
-    actions.add(file_mkdir, "file.mkdir");
-    actions.add(file_move, "file.move");
-    actions.add(file_properties, "file.properties");
-    actions.add(file_rename, "file.rename");
-    // actions.add(file_run, "file.run");
-    actions.add(file_sendto, "file.sendto");
-    actions.add(file_sync_dirs, "file.synchronize_directories");
-    // actions.add(file_umount, "file.umount");
-    actions.add(file_view, "file.view");
-    actions.add(help_about, "help.about");
-    actions.add(help_help, "help.help");
-    actions.add(help_keyboard, "help.keyboard");
-    actions.add(help_problem, "help.problem");
-    actions.add(help_web, "help.web");
-    actions.add(mark_compare_directories, "mark.compare_directories");
-    actions.add(mark_select_all, "mark.select_all");
-    actions.add(mark_toggle, "mark.toggle");
-    actions.add(mark_toggle_and_step, "mark.toggle_and_step");
-    actions.add(mark_unselect_all, "mark.unselect_all");
-    actions.add(no_action, "no.action");
-    actions.add(options_edit, "options.edit");
-    actions.add(options_edit_mime_types, "options.edit_mime_types");
-    actions.add(plugins_configure, "plugins.configure");
-    actions.add(plugins_execute_python, "plugins.execute_python");
-    actions.add(view_back, "view.back");
-    actions.add(view_equal_panes, "view.equal_panes");
-    actions.add(view_first, "view.first");
-    actions.add(view_forward, "view.forward");
-    actions.add(view_home, "view.home");
-    actions.add(view_in_active_pane, "view.in_active_pane");
-    actions.add(view_in_inactive_pane, "view.in_inactive_pane");
-    actions.add(view_in_left_pane, "view.in_left_pane");
-    actions.add(view_in_right_pane, "view.in_right_pane");
-    actions.add(view_last, "view.last");
-    actions.add(view_refresh, "view.refresh");
-    actions.add(view_root, "view.root");
-    actions.add(view_up, "view.up");
+    for (guint i=0; i<G_N_ELEMENTS(user_actions_data); ++i)
+    {
+        action_func.add(user_actions_data[i].func, user_actions_data[i].name);
+        action_name.add(user_actions_data[i].func, _(user_actions_data[i].description));
+    }
 
     register_action(GDK_F3, "file.view");
     register_action(GDK_F4, "file.edit");
@@ -275,8 +215,8 @@ void GnomeCmdUserActions::init()
     register_action(GDK_F6, "file.rename");
     register_action(GDK_F7, "file.mkdir");
     register_action(GDK_F8, "file.delete");
-    register_action(GDK_F9, "edit.search");
-    register_action(GDK_F10, "file.exit");
+    // register_action(GDK_F9, "edit.search");     //  do not register F9 here, as edit.search action wouldn't be checked for registration later
+    // register_action(GDK_F10, "file.exit");      //  do not register F10 here, as file.exit action wouldn't be checked for registration later
 
     load("key-bindings");
 
@@ -299,7 +239,14 @@ void GnomeCmdUserActions::init()
         register_action(GDK_CONTROL_MASK, GDK_F12, "edit.filter");
 
     if (!registered("edit.search"))
+    {
         register_action(GDK_MOD1_MASK, GDK_F7, "edit.search");
+#ifdef HAVE_GTK_2_10
+        register_action(GDK_SUPER_MASK, GDK_F, "edit.search");
+#else
+        register_action(GDK_MOD4_MASK, GDK_F, "edit.search");
+#endif
+    }
 
     if (!registered("file.advrename"))
     {
@@ -313,6 +260,9 @@ void GnomeCmdUserActions::init()
     if (!registered("file.edit_new_doc"))
         register_action(GDK_SHIFT_MASK, GDK_F4, "file.edit_new_doc");
 
+    if (!registered("file.exit"))
+        register_action(GDK_CONTROL_MASK, GDK_Q, "file.exit");
+
     if (!registered("file.external_view"))
         register_action(GDK_MOD1_MASK, GDK_F3, "file.external_view");
 
@@ -340,13 +290,11 @@ void GnomeCmdUserActions::init()
     {
         register_action(GDK_CONTROL_MASK, GDK_5, "plugins.execute_python", "md5sum");
         register_action(GDK_CONTROL_MASK, GDK_KP_5, "plugins.execute_python", "md5sum");
+        register_action(GDK_CONTROL_MASK, GDK_KP_Begin, "plugins.execute_python", "md5sum");
     }
 
     if (!registered("view.equal_panes"))
-    {
-        register_action(GDK_CONTROL_MASK | GDK_SHIFT_MASK, GDK_equal, "view.equal_panes");
         register_action(GDK_CONTROL_MASK | GDK_SHIFT_MASK, GDK_plus, "view.equal_panes");
-    }
 
     if (!registered("view.in_active_pane"))
         register_action(GDK_CONTROL_MASK, GDK_period, "view.in_active_pane");
@@ -369,7 +317,7 @@ void GnomeCmdUserActions::init()
     if (!registered("view.home"))
     {
         register_action(GDK_CONTROL_MASK, GDK_quoteleft, "view.home");
-        register_action(GDK_CONTROL_MASK, GDK_asciitilde, "view.home");
+        register_action(GDK_CONTROL_MASK | GDK_SHIFT_MASK, GDK_asciitilde, "view.home");
     }
 
     if (!registered("view.root"))
@@ -377,6 +325,12 @@ void GnomeCmdUserActions::init()
 
     if (!registered("view.refresh"))
         register_action(GDK_CONTROL_MASK, GDK_R, "view.refresh");
+
+    unregister(GDK_F9);                                 // unregister F9 if defined in [key-bindings]
+    register_action(GDK_F9, "edit.search");             // and overwrite it with edit.search action
+
+    unregister(GDK_F10);                                // unregister F10 if defined in [key-bindings]
+    register_action(GDK_F10, "file.exit");              // and overwrite it with file.exit action
  }
 
 
@@ -423,7 +377,7 @@ void GnomeCmdUserActions::load(const gchar *section)
         g_strstrip (action_name);
         g_strdown (action_name);
 
-        if (actions[action_name])
+        if (action_func[action_name])
         {
             guint keyval;
             guint state;
@@ -446,33 +400,18 @@ void GnomeCmdUserActions::load(const gchar *section)
 
 void GnomeCmdUserActions::write(const gchar *section)
 {
-    string section_path = G_DIR_SEPARATOR_S PACKAGE G_DIR_SEPARATOR_S;
+    string section_path  = G_DIR_SEPARATOR_S PACKAGE G_DIR_SEPARATOR_S;
            section_path += section;
-           section_path += G_DIR_SEPARATOR;
 
-    char *key = NULL;
-    char *action_name = NULL;
+    gnome_config_clean_section (section_path.c_str());
 
-    for (gpointer i=gnome_config_init_iterator (section_path.c_str()); (i=gnome_config_iterator_next (i, &key, &action_name)); )
+    for (ACTIONS_COLL::const_iterator i=action.begin(); i!=action.end(); ++i)
     {
-        string curr_key = key;
-        string norm_key = key2str(str2key(key));        // <ALT><Ctrl>F3 -> <ctrl><alt>f3
+        string path  = section_path;
+               path += G_DIR_SEPARATOR;
+               path += key2str(i->first);
 
-        if (!norm_key.empty() && curr_key!=norm_key)    // if (norm_key is valid && not 'canonical')
-        {
-            gnome_config_clean_key ((section_path+curr_key).c_str());
-            gnome_config_set_string ((section_path+norm_key).c_str(), action_name);
-        }
-
-        g_free (key);
-        g_free (action_name);
-    }
-
-    for (map<GdkEventKey, UserAction>::const_iterator i=action.begin(); i!=action.end(); ++i)
-    {
-        string path = section_path + key2str(i->first);
-
-        string action_name = actions[i->second.func];
+        string action_name = action_func[i->second.func];
 
         if (!i->second.user_data.empty())
         {
@@ -487,7 +426,7 @@ void GnomeCmdUserActions::write(const gchar *section)
 
 gboolean GnomeCmdUserActions::register_action(guint state, guint keyval, const gchar *name, const char *user_data)
 {
-    GnomeCmdUserActionFunc func = actions[name];
+    GnomeCmdUserActionFunc func = action_func[name];
 
     if (!func)
         return FALSE;
@@ -495,8 +434,11 @@ gboolean GnomeCmdUserActions::register_action(guint state, guint keyval, const g
     GdkEventKey event;
 
     event.keyval = keyval;
+#ifdef HAVE_GTK_2_10
+    event.state = state & (GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK | GDK_SUPER_MASK | GDK_HYPER_MASK | GDK_META_MASK);
+#else
     event.state = state & (GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK | GDK_MOD4_MASK);
-
+#endif
     if (action.find(event)!=action.end())
         return FALSE;
 
@@ -524,8 +466,11 @@ void GnomeCmdUserActions::unregister(guint state, guint keyval)
     GdkEventKey event;
 
     event.keyval = keyval;
+#ifdef HAVE_GTK_2_10
+    event.state = state & (GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK | GDK_SUPER_MASK | GDK_HYPER_MASK | GDK_META_MASK);
+#else
     event.state = state & (GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK | GDK_MOD4_MASK);
-
+#endif
     map <GdkEventKey, UserAction>::iterator pos = action.find(event);
 
     if (pos!=action.end())
@@ -535,12 +480,12 @@ void GnomeCmdUserActions::unregister(guint state, guint keyval)
 
 gboolean GnomeCmdUserActions::registered(const gchar *name)
 {
-    GnomeCmdUserActionFunc func = actions[name];
+    GnomeCmdUserActionFunc func = action_func[name];
 
     if (!func)
         return FALSE;
 
-    for (map<GdkEventKey, UserAction>::const_iterator i=action.begin(); i!=action.end(); ++i)
+    for (ACTIONS_COLL::const_iterator i=action.begin(); i!=action.end(); ++i)
         if (i->second.func==func)
             return TRUE;
 
@@ -553,13 +498,17 @@ gboolean GnomeCmdUserActions::registered(guint state, guint keyval)
     GdkEventKey event;
 
     event.keyval = keyval;
+#ifdef HAVE_GTK_2_10
+    event.state = state & (GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK | GDK_SUPER_MASK | GDK_HYPER_MASK | GDK_META_MASK);
+#else
     event.state = state & (GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK | GDK_MOD4_MASK);
+#endif
 
     return action.find(event)!=action.end();
 }
 
 
-gboolean GnomeCmdUserActions::handle_key_event(GnomeCmdMainWin *mw, GnomeCmdFileSelector *fs, GnomeCmdFileList *fl, GdkEventKey *event)
+gboolean GnomeCmdUserActions::handle_key_event(GnomeCmdMainWin *mw, GnomeCmdFileList *fl, GdkEventKey *event)
 {
     map <GdkEventKey, UserAction>::const_iterator pos = action.find(*event);
 
@@ -567,7 +516,7 @@ gboolean GnomeCmdUserActions::handle_key_event(GnomeCmdMainWin *mw, GnomeCmdFile
         return FALSE;
 
     DEBUG('a', "Key event:  %s (%#x)\n", key2str(*event).c_str(), event->keyval);
-    DEBUG('a', "Handling key event by %s()\n", actions[pos->second.func].c_str());
+    DEBUG('a', "Handling key event by %s()\n", action_func[pos->second.func].c_str());
 
     (*pos->second.func) (NULL, (gpointer) (pos->second.user_data.empty() ? NULL : pos->second.user_data.c_str()));
 
@@ -575,6 +524,83 @@ gboolean GnomeCmdUserActions::handle_key_event(GnomeCmdMainWin *mw, GnomeCmdFile
 }
 
 
+static int sort_by_description (const void *data1, const void *data2)
+{
+    const gchar *s1 = ((UserActionData *) data1)->description;
+    const gchar *s2 = ((UserActionData *) data2)->description;
+
+    if (!s1 && !s2)
+        return 0;
+
+    if (!s1)
+        return 1;
+
+    if (!s2)
+        return -1;
+
+    // compare s1 and s2 in UTF8 aware way, case insensitive
+    gchar *is1 = g_utf8_casefold (_(s1), -1);
+    gchar *is2 = g_utf8_casefold (_(s2), -1);
+
+    gint retval = g_utf8_collate (is1, is2);
+
+    g_free (is1);
+    g_free (is2);
+
+    return retval;
+}
+
+
+GtkTreeModel *gnome_cmd_user_actions_create_model ()
+{
+    UserActionData *data = (UserActionData *) g_memdup (user_actions_data, sizeof(user_actions_data));
+
+    qsort (data, G_N_ELEMENTS(user_actions_data), sizeof(UserActionData), sort_by_description);
+
+    GtkListStore *model = gtk_list_store_new (3, G_TYPE_POINTER, G_TYPE_STRING, G_TYPE_STRING);
+    GtkTreeIter iter;
+
+    for (guint i=0; i<G_N_ELEMENTS(user_actions_data); ++i)
+    {
+        gtk_list_store_append (model, &iter);
+
+        gtk_list_store_set (model, &iter,
+                                   0, data[i].func,
+                                   1, data[i].name,
+                                   2, _(data[i].description),
+                                   -1);
+    }
+
+    g_free (data);
+
+    return GTK_TREE_MODEL (model);
+}
+
+
+template <typename F>
+inline void get_file_list (string &s, GList *sfl, F f)
+{
+    vector<string> a;
+
+    for (GList *i = sfl; i; i = i->next)
+        a.push_back ((*f) (GNOME_CMD_FILE (i->data)));
+
+    join (s, a.begin(), a.end());
+}
+
+
+template <typename F, typename T>
+inline void get_file_list (string &s, GList *sfl, F f, T t)
+{
+    vector<string> a;
+
+    for (GList *i = sfl; i; i = i->next)
+        a.push_back ((*f) (GNOME_CMD_FILE (i->data), t));
+
+    join (s, a.begin(), a.end());
+}
+
+
 /***************************************/
 void no_action (GtkMenuItem *menuitem, gpointer not_used)
 {
@@ -584,8 +610,6 @@ void no_action (GtkMenuItem *menuitem, gpointer not_used)
 /************** File Menu **************/
 void file_copy (GtkMenuItem *menuitem, gpointer not_used)
 {
-    if (!main_win)  return;
-
     GnomeCmdFileSelector *src_fs = get_fs (ACTIVE);
     GnomeCmdFileSelector *dest_fs = get_fs (INACTIVE);
 
@@ -596,8 +620,6 @@ void file_copy (GtkMenuItem *menuitem, gpointer not_used)
 
 void file_move (GtkMenuItem *menuitem, gpointer not_used)
 {
-    if (!main_win)  return;
-
     GnomeCmdFileSelector *src_fs = get_fs (ACTIVE);
     GnomeCmdFileSelector *dest_fs = get_fs (INACTIVE);
 
@@ -709,29 +731,7 @@ void file_advrename (GtkMenuItem *menuitem, gpointer not_used)
 
 void file_sendto (GtkMenuItem *menuitem, gpointer not_used)
 {
-    string cmd = "nautilus-sendto";
-
-    GnomeCmdFileList *fl = get_fl (ACTIVE);
-    GList *sfl = gnome_cmd_file_list_get_selected_files (fl);
-    sfl = gnome_cmd_file_list_sort_selection (sfl, fl);
-
-    for (GList *i = sfl; i; i = i->next)
-    {
-        GnomeCmdFile *finfo = GNOME_CMD_FILE (i->data);
-
-        if (!finfo)
-            continue;
-
-        cmd += ' ';
-        cmd += (char *) gnome_cmd_file_get_quoted_real_path (finfo);
-    }
-
-    g_list_free (sfl);
-
-    g_print (_("running `%s'\n"), cmd.c_str());
-
-    if (cmd != "nautilus-sendto")
-        run_command (cmd.c_str(), FALSE);
+    command_execute (menuitem, (gpointer) "nautilus-sendto %s");
 }
 
 
@@ -894,41 +894,132 @@ void edit_filter (GtkMenuItem *menuitem, gpointer not_used)
 
 void edit_copy_fnames (GtkMenuItem *menuitem, gpointer not_used)
 {
-    static gchar sep[] = " ";
-
     GdkModifierType mask;
 
     gdk_window_get_pointer (NULL, NULL, NULL, &mask);
 
     GnomeCmdFileList *fl = get_fl (ACTIVE);
     GList *sfl = gnome_cmd_file_list_get_selected_files (fl);
-    gchar **fnames = g_new (char *, g_list_length (sfl) + 1);
-    gchar **f = fnames;
-
     sfl = gnome_cmd_file_list_sort_selection (sfl, fl);
 
-    for (GList *i = sfl; i; i = i->next)
-    {
-        GnomeCmdFile *finfo = GNOME_CMD_FILE (i->data);
+    string fnames;
 
-        if (finfo)
-          *f++ = (mask & GDK_SHIFT_MASK) ? (char *) gnome_cmd_file_get_real_path (finfo) :
-                                           (char *) gnome_cmd_file_get_name (finfo);
-    }
+    fnames.reserve(2000);
 
-    *f = NULL;
+    if (state_is_blank (mask))
+        get_file_list (fnames, sfl, gnome_cmd_file_get_name);
+    else
+        if (state_is_shift (mask))
+            get_file_list (fnames, sfl, gnome_cmd_file_get_real_path);
+        else
+            if (state_is_alt (mask))
+                get_file_list (fnames, sfl, gnome_cmd_file_get_uri_str, GNOME_VFS_URI_HIDE_PASSWORD);
 
-    gchar *s = g_strjoinv(sep,fnames);
+    gtk_clipboard_set_text (gtk_clipboard_get (GDK_SELECTION_CLIPBOARD), fnames.c_str(), -1);
 
-    gtk_clipboard_set_text (gtk_clipboard_get (GDK_SELECTION_CLIPBOARD), s, -1);
-
-    g_free (s);
     g_list_free (sfl);
-    g_free (fnames);
 }
 
 
 /************** Command Menu **************/
+void command_execute (GtkMenuItem *menuitem, gpointer command)
+{
+    g_return_if_fail (command != NULL);
+
+    DEBUG ('g', "invoking: %s\n", command);
+
+    string cmd;
+    string filename = "[f]";
+    string quoted_filename = "[F]";
+    string file_path = "[p]";
+    string quoted_file_path = "[P]";
+    string dir_path = "[d]";
+    string quoted_dir_path = "[D]";
+    string uri = "[U]";
+
+    GnomeCmdFileList *fl = get_fl (ACTIVE);
+    GList *sfl = gnome_cmd_file_list_get_selected_files (fl);
+    sfl = gnome_cmd_file_list_sort_selection (sfl, fl);
+
+    get_file_list (filename, sfl, gnome_cmd_file_get_name);
+    get_file_list (quoted_filename, sfl, gnome_cmd_file_get_quoted_name);
+    get_file_list (file_path, sfl, gnome_cmd_file_get_real_path);
+    get_file_list (quoted_file_path, sfl, gnome_cmd_file_get_quoted_real_path);
+    get_file_list (uri, sfl, gnome_cmd_file_get_uri_str, GNOME_VFS_URI_HIDE_NONE);
+
+    g_list_free (sfl);
+
+    GnomeCmdDir *dir = gnome_cmd_file_selector_get_directory (get_fs (ACTIVE));
+
+    stringify (dir_path, gnome_cmd_file_get_real_path (GNOME_CMD_FILE (dir)));
+    stringify (quoted_dir_path, gnome_cmd_file_get_quoted_real_path (GNOME_CMD_FILE (dir)));
+
+    gboolean percent = FALSE;
+
+    cmd.reserve(2000);
+
+    for (const char *s=(const char *) command; *s; ++s)
+    {
+        if (!percent)
+        {
+            percent = *s=='%';
+
+            if (!percent)
+                cmd += *s;
+
+            continue;
+        }
+
+        switch (*s)
+        {
+            case 'f':           // %f  file name (or list for multiple selections)
+                cmd += filename;
+                break;
+
+            case 'F':           // %F  quoted filename (or list for multiple selections)
+                cmd += quoted_filename;
+                break;
+
+            case 'p':           // %p  full file system path (or list for multiple selections)
+                cmd += file_path;
+                break;
+
+            case 'P':           // %P  quoted full file system path (or list for multiple selections)
+            case 's':           // %s  synonym for %P (for compatibility with previous versions of gcmd)
+                cmd += quoted_file_path;
+                break;
+
+            case 'u':           // %u  fully qualified URI for the file (or list for multiple selections)
+                cmd += uri;
+                break;
+
+            case 'd':           // %d  full path to the directory containing file
+                cmd += dir_path;
+                break;
+
+            case 'D':           // %D  quoted full path to the directory containg file
+                cmd += quoted_dir_path;
+                break;
+
+            default:
+                cmd += '%';
+            case '%':           // %%  percent sign
+                cmd += *s;
+                break;
+        }
+
+        percent = FALSE;
+    }
+
+    if (percent)
+        cmd += '%';
+
+    DEBUG ('g', "running: %s\n", cmd.c_str());
+
+    gnome_execute_shell (gnome_cmd_dir_is_local (dir) ? dir_path.c_str() : NULL, cmd.c_str());
+}
+
+
 void command_open_terminal (GtkMenuItem *menuitem, gpointer not_used)
 {
     gchar *dpath = gnome_cmd_file_get_real_path (GNOME_CMD_FILE (gnome_cmd_file_selector_get_directory (get_fs (ACTIVE))));
@@ -938,6 +1029,73 @@ void command_open_terminal (GtkMenuItem *menuitem, gpointer not_used)
 }
 
 
+inline void open_uri_in_nautilus (gchar *uri)
+{
+    if (!uri)
+        return;
+
+    char *argv[5];
+
+    argv[0] = "nautilus";
+    argv[1] = "--no-desktop";
+    argv[2] = "--no-default-window";
+    argv[3] = uri;
+    argv[4] = NULL;
+
+    GError *error = NULL;
+
+    if (!g_spawn_async (NULL, argv, NULL, GSpawnFlags (G_SPAWN_SEARCH_PATH | G_SPAWN_STDOUT_TO_DEV_NULL), NULL, NULL, NULL, &error))
+        gnome_cmd_error_message (_("Unable to start Nautilus."), error);
+
+    g_free (uri);
+}
+
+
+void command_open_nautilus (GtkMenuItem *menuitem, gpointer not_used)
+{
+    GnomeCmdFile *f = gnome_cmd_file_list_get_selected_file (get_fl (ACTIVE));
+
+    open_uri_in_nautilus (gnome_cmd_file_get_uri_str (GNOME_CMD_IS_DIR (f) ? f : GNOME_CMD_FILE (gnome_cmd_file_selector_get_directory (get_fs (ACTIVE)))));
+}
+
+
+void command_open_nautilus_in_cwd (GtkMenuItem *menuitem, gpointer not_used)
+{
+    open_uri_in_nautilus (gnome_cmd_file_get_uri_str (GNOME_CMD_FILE (gnome_cmd_file_selector_get_directory (get_fs (ACTIVE)))));
+}
+
+
+void command_root_mode (GtkMenuItem *menuitem, gpointer not_used)
+{
+    char *su;
+
+    su = g_find_program_in_path ("gksudo");
+    if  (!su)
+        su = g_find_program_in_path ("gksu");
+    if  (!su)
+        su = g_find_program_in_path ("kdesu");
+
+    if  (!su)
+    {
+        gnome_cmd_show_message (NULL, _("gksu or kdesu is not found."));
+        return ;
+    }
+
+    char *argv[3];
+
+    argv[0] = su;
+    argv[1] = g_get_prgname ();
+    argv[2] = NULL;
+
+    GError *error = NULL;
+
+    if (!g_spawn_async (NULL, argv, NULL, GSpawnFlags (G_SPAWN_STDOUT_TO_DEV_NULL | G_SPAWN_STDERR_TO_DEV_NULL), NULL, NULL, NULL, &error))
+        gnome_cmd_error_message (_("Unable to start GNOME Commander in root mode."), error);
+
+    g_free (su);
+}
+
+
 /************** Mark Menu **************/
 void mark_toggle (GtkMenuItem *menuitem, gpointer not_used)
 {
@@ -1114,25 +1272,25 @@ void view_equal_panes (GtkMenuItem *menuitem, gpointer not_used)
 
 void view_in_left_pane (GtkMenuItem *menuitem, gpointer not_used)
 {
-    gnome_cmd_file_selector_set_same_directory ((GnomeCmdMainWin *) GTK_WIDGET (main_win), LEFT, RIGHT);
+    gnome_cmd_file_selector_set_directory_to_opposite ((GnomeCmdMainWin *) GTK_WIDGET (main_win), LEFT);
 }
 
 
 void view_in_right_pane (GtkMenuItem *menuitem, gpointer not_used)
 {
-    gnome_cmd_file_selector_set_same_directory ((GnomeCmdMainWin *) GTK_WIDGET (main_win), RIGHT, LEFT);
+    gnome_cmd_file_selector_set_directory_to_opposite ((GnomeCmdMainWin *) GTK_WIDGET (main_win), RIGHT);
 }
 
 
 void view_in_active_pane (GtkMenuItem *menuitem, gpointer not_used)
 {
-    gnome_cmd_file_selector_set_same_directory ((GnomeCmdMainWin *) GTK_WIDGET (main_win), ACTIVE, INACTIVE);
+    gnome_cmd_file_selector_set_directory_to_opposite ((GnomeCmdMainWin *) GTK_WIDGET (main_win), ACTIVE);
 }
 
 
 void view_in_inactive_pane (GtkMenuItem *menuitem, gpointer not_used)
 {
-    gnome_cmd_file_selector_set_same_directory ((GnomeCmdMainWin *) GTK_WIDGET (main_win), INACTIVE, ACTIVE);
+    gnome_cmd_file_selector_set_directory_to_opposite ((GnomeCmdMainWin *) GTK_WIDGET (main_win), INACTIVE);
 }
 
 
@@ -1159,6 +1317,12 @@ void options_edit (GtkMenuItem *menuitem, gpointer not_used)
 }
 
 
+void options_edit_shortcuts (GtkMenuItem *menuitem, gpointer not_used)
+{
+    gnome_cmd_key_shortcuts_dialog_new (gcmd_user_actions);
+}
+
+
 void options_edit_mime_types (GtkMenuItem *menuitem, gpointer not_used)
 {
     edit_mimetypes (NULL, FALSE);
@@ -1180,13 +1344,13 @@ void connections_new (GtkMenuItem *menuitem, gpointer not_used)
 }
 
 
-void connections_change (GtkMenuItem *menuitem, gpointer con)
+void connections_change (GtkMenuItem *menuitem, gpointer con)           // this function is NOT exposed to user as UserAction
 {
     gnome_cmd_file_selector_set_connection (get_fs (ACTIVE), (GnomeCmdCon *) con);
 }
 
 
-void connections_close (GtkMenuItem *menuitem, gpointer con)
+void connections_close (GtkMenuItem *menuitem, gpointer con)            // this function is NOT exposed to user as UserAction
 {
     GnomeCmdFileSelector *active = get_fs (ACTIVE);
     GnomeCmdFileSelector *inactive = get_fs (INACTIVE);
@@ -1375,19 +1539,19 @@ void help_about (GtkMenuItem *menuitem, gpointer not_used)
     gchar *license_trans = g_strjoin ("\n\n", _(license[0]), _(license[1]), _(license[2]), NULL);
 
     gtk_show_about_dialog (GTK_WINDOW (main_win),
-                   "name", "GNOME Commander",
-                   "version", VERSION,
-                   "comments", _(comments),
-                   "copyright", copyright,
-                   "license", license_trans,
-                   "wrap-license", TRUE,
-                   "authors", authors,
-                   "documenters", documenters,
-                   "logo-icon-name", PACKAGE_NAME,
-                   "translator-credits", _("translator-credits"),
-                   "website", "http://www.nongnu.org/gcmd",
-                   "website-label", "GNOME Commander Website",
-                   NULL);
+                           "name", "GNOME Commander",
+                           "version", VERSION,
+                           "comments", _(comments),
+                           "copyright", copyright,
+                           "license", license_trans,
+                           "wrap-license", TRUE,
+                           "authors", authors,
+                           "documenters", documenters,
+                           "logo-icon-name", PACKAGE_NAME,
+                           "translator-credits", _("translator-credits"),
+                           "website", "http://www.nongnu.org/gcmd",
+                           "website-label", "GNOME Commander Website",
+                           NULL);
 
     g_free (license_trans);
 }
