@@ -1,5 +1,5 @@
 /*
-    GNOME Commander - A GNOME based file manager 
+    GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
 
     This program is free software; you can redistribute it and/or modify
@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #ifndef __HISTORY_H__
@@ -22,10 +22,10 @@
 
 typedef struct
 {
-	GList *ents;
-	GList *pos;
-	gint max;
-	gboolean lock;
+    GList *ents;
+    GList *pos;
+    gint max;
+    gboolean lock;
 } History;
 
 
@@ -37,7 +37,9 @@ void     history_add (History *history, const gchar *text);
 gboolean history_can_back (History *history);
 gboolean history_can_forward (History *history);
 
+const gchar   *history_first (History *history);
 const gchar   *history_back (History *history);
 const gchar   *history_forward (History *history);
+const gchar   *history_last (History *history);
 
-#endif //__HISTORY_H__
+#endif // __HISTORY_H__
